@@ -26,6 +26,8 @@ class InstallLayer(tcl_ptc.BasePTCLayer):
             image=self.portal['document_icon.gif']._readFile(False))
 
         self.login()
+        self.portal.portal_membership.getMemberById(
+            ptc.default_user).setProperties(fullname='Foo Full Name')
         self.folder.invokeFactory(
             type_name='Folder', id='slideshow', title='Slideshow')
         self.folder.slideshow.invokeFactory(
